/********************************** (C) COPYRIGHT *******************************
 * File Name          : usb_desc.c
 * Author             : WCH
 * Version            : V1.0.0
 * Date               : 2023/04/06
 * Description        : Main program body.
 *********************************************************************************
 * Copyright (c) 2021 Nanjing Qinheng Microelectronics Co., Ltd.
 * Attention: This software (modified or not) and binary are used for
 * microcontroller manufactured by Nanjing Qinheng Microelectronics.
 *******************************************************************************/
#include "usb_desc.h"

/* Device Descriptor */
const uint8_t MyDevDescr[] =
    {
        0x12,       // bLength
        0x01,       // bDescriptorType (Device)
        0x10, 0x02, // bcdUSB 2.10
        0xFF,       // bDeviceClass
        0xFF,       // bDeviceSubClass
        0xFF,       // bDeviceProtocol
        0x40,       // bMaxPacketSize0 64
        (uint8_t)DEF_USB_VID, (uint8_t)(DEF_USB_VID >> 8),  // idVendor 0x1A86
        (uint8_t)DEF_USB_PID, (uint8_t)(DEF_USB_PID >> 8),  // idProduct 0x5537
        DEF_IC_PRG_VER, 0x00, // bcdDevice 0.01
        0x01,       // iManufacturer (String Index)
        0x02,       // iProduct (String Index)
        0x00,       // iSerialNumber (String Index)
        0x01,       // bNumConfigurations 1
    };

/* Configuration Descriptor */
const uint8_t MyCfgDescr[] =
    {
        0x09,       // bLength
        0x02,       // bDescriptorType (Configuration)
        32, 0x00, // wTotalLength 25
        0x01,       // bNumInterfaces 1
        0x01,       // bConfigurationValue
        0x00,       // iConfiguration (String Index)
        0x80,       // bmAttributes
        0x32,       // bMaxPower 100mA

        0x09,       // bLength
        0x04,       // bDescriptorType (Interface)
        0x00,       // bInterfaceNumber 0
        0x00,       // bAlternateSetting
        0x02,       // bNumEndpoints 2
        0xFF,       // bInterfaceClass
        0xFF,       // bInterfaceSubClass
        0xFF,       // bInterfaceProtocol
        0x00,       // iInterface (String Index)

        0x07,       // bLength
        0x05,       // bDescriptorType (Endpoint)
        0x01,       // bEndpointAddress (OUT/H2D)
        0x02,       // bmAttributes (Bulk)
        (uint8_t)DEF_USBD_ENDP1_SIZE, (uint8_t)(DEF_USBD_ENDP1_SIZE >> 8), // wMaxPacketSize 64
        0x00,       // bInterval 0 (unit depends on device speed)

        0x07,       // bLength
        0x05,       // bDescriptorType (Endpoint)
        0x82,       // bEndpointAddress (IN/D2H)
        0x02,       // bmAttributes (Bulk)
        (uint8_t)DEF_USBD_ENDP2_SIZE, (uint8_t)(DEF_USBD_ENDP2_SIZE >> 8), // wMaxPacketSize 64
        0x00,       // bInterval 0 (unit depends on device speed)
    };

const uint8_t bosDesc[] =
    {
        // BOS Base Descriptor
        0x05,//bLength
        0x0f,       //bDescriptorType
        0x21, 0x00, // wTotalLength
        0x01,       // bNumDeviceCaps

        // BOS Device Capability Descriptor
        0x1c,// bLength
        0x10,       // bDescriptorType
        0x05,       // bDevCapabilityType
        0x00,       // bReserved
        0xdf, 0x60, 0xdd, 0xd8, 0x89, 0x45, 0xc7, 0x4c, // bPlatformCapabilityUUID_16
        0x9c, 0xd2, 0x65, 0x9d, 0x9e, 0x64, 0x8a, 0x9f, // bPlatformCapabilityUUID_16
        0x00, 0x00, 0x03, 0x06, // dwWindowsVersion Win8.1+
        0xa2, 0x00, // wDescriptorSetTotalLength    【①】
        0x01,       // bVendorCode    【②】
        0x00,       // bAltEnumCode
    };

const uint8_t msos2Desc[] =
    {
        // MSOS2.0 Descriptor Set Descriptor
        0x0a, 0x00, // wLength
        0x00, 0x00, // wDescriptorType
        0x00, 0x00, 0x03, 0x06, // dwWindowsVersion
        0xa2, 0x00, // wDescriptorSetTotalLength    【①】

        /*
         // MSOS2.0 Function Subset Descriptor
         0x08, 0x00, // wLength
         0x02, 0x00, // wDescriptorType
         0x00, // bFirstInterface        【②】
         0x00, // bReserved
         0xa0, 0x00, // wSubsetLength
         */

        // MSOS2.0 Compatible ID Descriptor
        0x14, 0x00, // wLength
        0x03, 0x00, // wDescriptorType
        'W', 'I', 'N', 'U', 'S', 'B', 0x00, 0x00, // cCID_8
        0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, // cSubCID_8

        // MSOS2.0 Registry Property Descriptor
        0x84, 0x00, // wLength
        0x04, 0x00, // wDescriptorType
        0x07, 0x00, // wPropertyDataType

        0x2a, 0x00, // wPropertyNameLength
        // String "DeviceInterfaceGUIDs"
        'D', 0x00, 'e', 0x00, 'v', 0x00, 'i', 0x00,
        'c', 0x00, 'e', 0x00, 'I', 0x00, 'n', 0x00,
        't', 0x00, 'e', 0x00, 'r', 0x00, 'f', 0x00,
        'a', 0x00, 'c', 0x00, 'e', 0x00, 'G', 0x00,
        'U', 0x00, 'I', 0x00, 'D', 0x00, 's', 0x00,
        0x00, 0x00,

        0x50, 0x00, // wPropertyDataLength
        // String "{CDB3B5AD-293B-4663-AA36-1AAE46463776}" 【③】
        '{', 0x00, 'C', 0x00, 'D', 0x00, 'B', 0x00,
        '3', 0x00, 'B', 0x00, '5', 0x00, 'A', 0x00,
        'D', 0x00, '-', 0x00, '2', 0x00, '9', 0x00,
        '3', 0x00, 'B', 0x00, '-', 0x00, '4', 0x00,
        '6', 0x00, '6', 0x00, '3', 0x00, '-', 0x00,
        'A', 0x00, 'A', 0x00, '3', 0x00, '6', 0x00,
        '-', 0x00, '1', 0x00, 'A', 0x00, 'A', 0x00,
        'E', 0x00, '4', 0x00, '6', 0x00, '4', 0x00,
        '6', 0x00, '3', 0x00, '7', 0x00, '7', 0x00,
        '6', 0x00, '}', 0x00, 0x00, 0x00, 0x00, 0x00,
    };

/* Language Descriptor */
const uint8_t MyLangDescr[] =
    {
        0x04, 0x03, 0x09, 0x04
    };

/* Manufacturer Descriptor */
const uint8_t MyManuInfo[] =
    {
        0x0E, 0x03, 'w', 0, 'c', 0, 'h', 0, '.', 0, 'c', 0, 'n', 0
    };

/* Product Information */
const uint8_t MyProdInfo[] =
    {
        0x12, 0x03, 'C', 0, 'H', 0, '3', 0, '2', 0, 'X', 0, '0', 0
        , '3', 0, '5', 0
    };

/* Serial Number Information */
const uint8_t MySerNumInfo[] =
    {
        0x16, 0x03, '0', 0, '1', 0, '2', 0, '3', 0, '4', 0, '5', 0
        , '6', 0, '7', 0, '8', 0, '9', 0
    };

